@@ -4,10 +4,15 @@ package API::Instagram::Tag;
 
 use Moo;
 
-has _api        => ( is => 'ro', required => 1 );
-has name        => ( is => 'ro', required => 1 );
+has _api  => ( is => 'ro', required => 1 );
+has name  => ( is => 'ro', required => 1 );
+has _data => ( is => 'rwp', lazy => 1, builder => 1, clearer => 1 );
 
-sub media_count { shift->_load('media_count') }
+sub media_count {
+	my $self = shift;
+	$self->_clear_data if shift;
+	$self->_data->{media_count}
+}
 
 
 sub recent_medias {
@@ -16,14 +21,10 @@ sub recent_medias {
 	$self->_api->_recent_medias( $url, @_ );
 }
 
-sub _load {
+sub _build__data {
 	my $self = shift;
-	my $attr = shift;
-
 	my $url  = sprintf "tags/%s", $self->name;
-	my $res  = $self->_api->_request_data($url);
-
-	$attr ? $res->{$attr} : $res;
+	$self->_api->_request_data( $url );
 }
 
 1;
@@ -40,7 +41,7 @@ API::Instagram::Tag - Instagram Tag Object
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
